==> next-ft-api-client-3.12.0.tgz: package/src/content.js <==
'use strict';

var capiV2 = require('./utils/capi-v2');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var eagerFetch = require('./utils/eager-fetch');
var elasticAgent = require('./utils/elastic-agent');
var signedFetch = require('./utils/elastic-fetch');

module.exports = function(opts) {
	var useElasticSearch = opts.useElasticSearch;
	var useElasticSearchOnAws = opts.useElasticSearchOnAws;
	var uuid = opts.uuid;
	var returnMany = true;
	var type = opts.type || 'unknown';
	var retry = opts.retry;

	if (!Array.isArray(uuid)) {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch) {
		return (useElasticSearchOnAws ? signedFetch : eagerFetch)('https://' + process.env.ELASTIC_SEARCH_HOST + '/v2_api_v2/item/_mget', {
				retry: 0,
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000,
				agent: elasticAgent
			})
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv2 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	}
	return Promise.all(uuid.map(function(uuid) {
		return capiV2({
			uuid: uuid,
			path: '/' + (opts.metadata ? 'enriched' : '') + 'content/' + uuid,
			type: type,
			retry: retry
		});
	}))
		.then(function(items) {
			if (returnMany) {
				return items;
			}
			return items[0];
		});
};

==> next-ft-api-client-3.13.0.tgz: package/src/content.js <==
'use strict';

var capiV2 = require('./utils/capi-v2');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var elasticAgent = require('./utils/elastic-agent');
var signedFetch = require('signed-aws-es-fetch');

module.exports = function(opts) {
	var useElasticSearch = opts.useElasticSearch;
	var uuid = opts.uuid;
	var returnMany = true;
	var type = opts.type || 'unknown';
	var retry = opts.retry;

	if (!Array.isArray(uuid)) {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch) {
		return signedFetch('https://next-elastic.ft.com/v2_api_v2/item/_mget', {
				retry: 0,
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000,
				agent: elasticAgent
			})
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv2 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	}
	return Promise.all(uuid.map(function(uuid) {
		return capiV2({
			uuid: uuid,
			path: '/' + (opts.metadata ? 'enriched' : '') + 'content/' + uuid,
			type: type,
			retry: retry
		});
	}))
		.then(function(items) {
			if (returnMany) {
				return items;
			}
			return items[0];
		});
};
